@@ -1,6 +1,6 @@
 package AnyEvent::ProcessPool;
 # ABSTRACT: Asynchronously runs code concurrently in a pool of perl processes
-$AnyEvent::ProcessPool::VERSION = '0.04';
+$AnyEvent::ProcessPool::VERSION = '0.05';
 use strict;
 use warnings;
 use Carp;
@@ -15,6 +15,7 @@ sub new {
   my $self = bless {
     workers  => $param{workers} || cpu_count,
     limit    => $param{limit},
+    include  => $param{include},
     pool     => [], # array of AE::PP::Process objects
     queue    => [], # array of [id, code] tasks
     complete => {}, # task_id => condvar: signals result to caller
@@ -23,7 +24,10 @@ sub new {
 
   # Initialize workers but do not yet wait for them to be started
   foreach (1 .. $self->{workers}) {
-    my $worker = AnyEvent::ProcessPool::Process->new(limit => $self->{limit});
+    my $worker = AnyEvent::ProcessPool::Process->new(
+      limit   => $self->{limit},
+      include => $self->{include},
+    );
     push @{$self->{pool}}, $worker;
   }
 
@@ -98,7 +102,6 @@ sub process_queue {
   }
 }
 
-
 1;
 
 __END__
@@ -113,7 +116,7 @@ AnyEvent::ProcessPool - Asynchronously runs code concurrently in a pool of perl
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -122,6 +125,7 @@ version 0.04
   my $pool = AnyEvent::ProcessPool->new(
     workers => 8,
     limit   => 10,
+    include => ['lib', 'some/lib/path'],
   );
 
   my $condvar = $pool->async(sub{
@@ -152,6 +156,11 @@ performing C<limit> tasks. This can be useful when calling code which may be
 leaky. When unspecified or set to zero, worker processes will only be restarted
 if it unexpectedly fails.
 
+=head2 include
+
+An optional array ref of paths to add to the perl command string used to start
+the sub-process worker.
+
 =head1 METHODS
 
 =head2 async
@@ -213,6 +222,12 @@ Thrown when a worker sub-process exits as a result of a signal received.
 Thrown when a worker sub-process terminates with a non-zero exit code. The
 worker will be automatically restarted.
 
+=head1 INCOMPATIBILITIES
+
+Will not work on MSWin32 (although Cygwin should be fine) due to lack of
+support for non-blocking writes to process pipes (see notes in
+L<AnyEvent::Open3::Simple>.
+
 =head1 SEE ALSO
 
 =over
