@@ -1,6 +1,6 @@
 package AnyEvent::ProcessPool::Process;
 # ABSTRACT: Manages an individual worker process
-$AnyEvent::ProcessPool::Process::VERSION = '0.04';
+$AnyEvent::ProcessPool::Process::VERSION = '0.05';
 use strict;
 use warnings;
 
@@ -20,9 +20,12 @@ my $cmd = join ' ', @inc, q(-MAnyEvent::ProcessPool::Worker -e 'AnyEvent::Proces
 
 sub new {
   my ($class, %param) = @_;
+  my $include = $param{include} || [];
+
   return bless {
     id      => next_id,
     limit   => $param{limit},
+    include => join(' ', map { sprintf('-I%s', backslash($_)) } @$include),
     started => undef,
     process => undef,
     ps      => undef,
@@ -102,7 +105,7 @@ sub start {
     },
   );
 
-  $self->{process}->run("$perl $cmd", sub{
+  $self->{process}->run("$perl $self->{include} $cmd", sub{
     my $ps = shift;
     $ps->user({reqs => $self->{limit}}) if $self->{limit};
     $self->{ps} = $ps;
@@ -136,7 +139,7 @@ AnyEvent::ProcessPool::Process - Manages an individual worker process
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 AUTHOR
 
