@@ -1,5 +1,6 @@
 package AnyEvent::ProcessPool::Task;
-$AnyEvent::ProcessPool::Task::VERSION = '0.04';
+# ABSTRACT: A serializable work unit
+$AnyEvent::ProcessPool::Task::VERSION = '0.05';
 use strict;
 use warnings;
 use Carp;
@@ -64,11 +65,11 @@ __END__
 
 =head1 NAME
 
-AnyEvent::ProcessPool::Task
+AnyEvent::ProcessPool::Task - A serializable work unit
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 AUTHOR
 
